@@ -20,7 +20,7 @@ OpenTracing::Role::SpanContext - Role for OpenTracing implementations.
 
 
 
-our $VERSION = '0.08_004';
+our $VERSION = '0.08_005';
 
 
 
@@ -128,7 +128,9 @@ sub with_baggage_items {
 #
 sub _clone {
     my ( $self, @args ) = @_;
-    ref( $self )->new( %$self, @args );
+    
+    bless { %$self, @args }, ref $self;
+    
 }
 
 
